# Changelog

## 1.2.0 - 2025-09-14

* Adds `--alt-texts` to pass images alt texts from the CLI
* Adds possibility to post image(s) without text

## 1.1.4 - 2025-09-14

* Adds support for Pyhton 3.14
* Drops support for Python 3.9 (end of life in 17 days)
